==> sovix-0.0.1.5.tar.gz: sovix-0.0.1.5/websrc/Upload_file.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
This entire article is distributed under the GNU Free Documentation
License, Version 1.2 or any later version.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
if (isset($_SESSION['sovix__user'])) {

  $sovix__destination=$_POST['sovix__destination'];
  if (empty($sovix__destination)) {
  ?>

 <form enctype="multipart/form-data" action="" method="POST">
    Select source: <input name="sovix__source" type="file" />
    <p></p>
    Select destination: <input type="text" name="sovix__destination" />
    <p></p>
    <input type="submit" value="Upload" />
    </form>

    <?php
    }
  else {
    $sovix__destination = "$sovix__directory__document_root" . $sovix__destination . basename( $_FILES['sovix__source']['sovix__array__bookmarks__array__name']) ;
    $sovix__ok=1;
    if(move_uploaded_file($_FILES['sovix__source']['tmp_name'], $sovix__destination))
      {echo "The file ". $_FILES['sovix__source']['sovix__array__bookmarks__array__name']. " has been uploaded to <a href=\"".str_replace("$sovix__directory__document_root", "", $sovix__destination)."\">".$sovix__destination."</a>";}
    else {echo "Sorry, there was a problem uploading your file.";}
  }
}
else echo "You are not logged in";
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>

==> sovix-0.0.1.6.tar.gz: sovix-0.0.1.6/websrc/Upload_file.php <==
<?php /* Copyright (C) 2006, 2007 David Englund.

This file is part of GNU Sovix.

GNU Sovix is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as
published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

GNU Sovix is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with GNU Sovix.  If not, see <http://www.gnu.org/licenses/>.

The text in $sovix__page__copyright doesn't apply to this file, but
rather to the pages it generates. */

$sovix__page__copyright="Copyright (C) 2006, 2007 David Englund.
Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.2 or any
later version published by the Free Software Foundation; with no Invariant
Sections, with no Front-Cover Texts, and with no Back-Cover Texts.";
if (isset($_GET['sovix__directory__src'])) {
  $sovix__directory__src=$_GET['sovix__directory__src'];
  $sovix__directory__dotsovix=$_GET['sovix__directory__dotsovix'];
 }
else {
  $sovix__directory__src=$_SERVER['DOCUMENT_ROOT']."/sovix/src";
  $sovix__directory__dotsovix=$_SERVER['DOCUMENT_ROOT']."/sovix/dotsovix";
}
require_once "$sovix__directory__src/header.inc"; ?>

<?php
if (isset($_SESSION['sovix__user'])) {

  $sovix__destination=$_POST['sovix__destination'];
  if (empty($sovix__destination)) {
  ?>

 <form enctype="multipart/form-data" action="" method="POST">
    Select source: <input name="sovix__source" type="file" />
    <p></p>
    Select destination: <input type="text" name="sovix__destination" />
    <p></p>
    <input type="submit" value="Upload" />
    </form>

    <?php
    }
  else {
    $sovix__destination = "$sovix__directory__document_root" . $sovix__destination . basename( $_FILES['sovix__source']['sovix__array__bookmarks__array__name']) ;
    $sovix__ok=1;
    if(move_uploaded_file($_FILES['sovix__source']['tmp_name'], $sovix__destination))
      {echo "The file ". $_FILES['sovix__source']['sovix__array__bookmarks__array__name']. " has been uploaded to <a href=\"".str_replace("$sovix__directory__document_root", "", $sovix__destination)."\">".$sovix__destination."</a>";}
    else {echo "Sorry, there was a problem uploading your file.";}
  }
}
else echo "You are not logged in";
?>

<?php require_once "$sovix__directory__src/footer.inc"; ?>
